@@ -17,7 +17,9 @@ limitations under the License.
 package protocol
 
 import (
-	"github.com/SAP/go-hdb/internal/bufio"
+	"fmt"
+
+	"github.com/SAP/go-hdb/internal/protocol/encoding"
 )
 
 //rows affected
@@ -27,43 +29,36 @@ const (
 )
 
 //rows affected
-type rowsAffected struct {
-	rows    []int32
-	_numArg int
+type rowsAffected []int32
+
+func (r rowsAffected) String() string {
+	return fmt.Sprintf("%v", []int32(r))
 }
 
-func (r *rowsAffected) kind() partKind {
-	return pkRowsAffected
-}
-
-func (r *rowsAffected) setNumArg(numArg int) {
-	r._numArg = numArg
-}
-
-func (r *rowsAffected) read(rd *bufio.Reader) error {
-	if r.rows == nil || r._numArg > cap(r.rows) {
-		r.rows = make([]int32, r._numArg)
+func (r *rowsAffected) reset(numArg int) {
+	if r == nil || numArg > cap(*r) {
+		*r = make(rowsAffected, numArg)
 	} else {
-		r.rows = r.rows[:r._numArg]
+		*r = (*r)[:numArg]
 	}
-
-	for i := 0; i < r._numArg; i++ {
-		r.rows[i] = rd.ReadInt32()
-		if trace {
-			outLogger.Printf("rows affected %d: %d", i, r.rows[i])
-		}
-	}
-
-	return rd.GetError()
 }
 
-func (r *rowsAffected) total() int64 {
-	if r.rows == nil {
+func (r *rowsAffected) decode(dec *encoding.Decoder, ph *partHeader) error {
+	r.reset(ph.numArg())
+
+	for i := 0; i < ph.numArg(); i++ {
+		(*r)[i] = dec.Int32()
+	}
+	return dec.Error()
+}
+
+func (r rowsAffected) total() int64 {
+	if r == nil {
 		return 0
 	}
 
 	total := int64(0)
-	for _, rows := range r.rows {
+	for _, rows := range r {
 		if rows > 0 {
 			total += int64(rows)
 		}
